==> zio-aws-ec2_2.12-5.17.130.5-sources.jar: zio/aws/ec2/model/ModifyVpnTunnelOptionsRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.VpnConnectionId
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class ModifyVpnTunnelOptionsRequest(
    vpnConnectionId: VpnConnectionId,
    vpnTunnelOutsideIpAddress: String,
    tunnelOptions: zio.aws.ec2.model.ModifyVpnTunnelOptionsSpecification
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ModifyVpnTunnelOptionsRequest = {
    import ModifyVpnTunnelOptionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ModifyVpnTunnelOptionsRequest
      .builder()
      .vpnConnectionId(
        VpnConnectionId.unwrap(vpnConnectionId): java.lang.String
      )
      .vpnTunnelOutsideIpAddress(vpnTunnelOutsideIpAddress: java.lang.String)
      .tunnelOptions(tunnelOptions.buildAwsValue())
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ModifyVpnTunnelOptionsRequest.ReadOnly =
    zio.aws.ec2.model.ModifyVpnTunnelOptionsRequest.wrap(buildAwsValue())
}
object ModifyVpnTunnelOptionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ModifyVpnTunnelOptionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ModifyVpnTunnelOptionsRequest =
      zio.aws.ec2.model.ModifyVpnTunnelOptionsRequest(
        vpnConnectionId,
        vpnTunnelOutsideIpAddress,
        tunnelOptions.asEditable
      )
    def vpnConnectionId: VpnConnectionId
    def vpnTunnelOutsideIpAddress: String
    def tunnelOptions
        : zio.aws.ec2.model.ModifyVpnTunnelOptionsSpecification.ReadOnly
    def getVpnConnectionId: ZIO[Any, Nothing, VpnConnectionId] =
      ZIO.succeed(vpnConnectionId)
    def getVpnTunnelOutsideIpAddress: ZIO[Any, Nothing, String] =
      ZIO.succeed(vpnTunnelOutsideIpAddress)
    def getTunnelOptions: ZIO[
      Any,
      Nothing,
      zio.aws.ec2.model.ModifyVpnTunnelOptionsSpecification.ReadOnly
    ] = ZIO.succeed(tunnelOptions)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ModifyVpnTunnelOptionsRequest
  ) extends zio.aws.ec2.model.ModifyVpnTunnelOptionsRequest.ReadOnly {
    override val vpnConnectionId: VpnConnectionId =
      zio.aws.ec2.model.primitives.VpnConnectionId(impl.vpnConnectionId())
    override val vpnTunnelOutsideIpAddress: String =
      impl.vpnTunnelOutsideIpAddress(): String
    override val tunnelOptions
        : zio.aws.ec2.model.ModifyVpnTunnelOptionsSpecification.ReadOnly =
      zio.aws.ec2.model.ModifyVpnTunnelOptionsSpecification
        .wrap(impl.tunnelOptions())
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ModifyVpnTunnelOptionsRequest
  ): zio.aws.ec2.model.ModifyVpnTunnelOptionsRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ec2_2.13-6.20.78.1-sources.jar: zio/aws/ec2/model/ModifyVpnTunnelOptionsRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.VpnConnectionId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ModifyVpnTunnelOptionsRequest(
    vpnConnectionId: VpnConnectionId,
    vpnTunnelOutsideIpAddress: String,
    tunnelOptions: zio.aws.ec2.model.ModifyVpnTunnelOptionsSpecification,
    skipTunnelReplacement: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ModifyVpnTunnelOptionsRequest = {
    import ModifyVpnTunnelOptionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ModifyVpnTunnelOptionsRequest
      .builder()
      .vpnConnectionId(
        VpnConnectionId.unwrap(vpnConnectionId): java.lang.String
      )
      .vpnTunnelOutsideIpAddress(vpnTunnelOutsideIpAddress: java.lang.String)
      .tunnelOptions(tunnelOptions.buildAwsValue())
      .optionallyWith(
        skipTunnelReplacement.map(value => value: java.lang.Boolean)
      )(_.skipTunnelReplacement)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ModifyVpnTunnelOptionsRequest.ReadOnly =
    zio.aws.ec2.model.ModifyVpnTunnelOptionsRequest.wrap(buildAwsValue())
}
object ModifyVpnTunnelOptionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ModifyVpnTunnelOptionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ModifyVpnTunnelOptionsRequest =
      zio.aws.ec2.model.ModifyVpnTunnelOptionsRequest(
        vpnConnectionId,
        vpnTunnelOutsideIpAddress,
        tunnelOptions.asEditable,
        skipTunnelReplacement.map(value => value)
      )
    def vpnConnectionId: VpnConnectionId
    def vpnTunnelOutsideIpAddress: String
    def tunnelOptions
        : zio.aws.ec2.model.ModifyVpnTunnelOptionsSpecification.ReadOnly
    def skipTunnelReplacement: Optional[Boolean]
    def getVpnConnectionId: ZIO[Any, Nothing, VpnConnectionId] =
      ZIO.succeed(vpnConnectionId)
    def getVpnTunnelOutsideIpAddress: ZIO[Any, Nothing, String] =
      ZIO.succeed(vpnTunnelOutsideIpAddress)
    def getTunnelOptions: ZIO[
      Any,
      Nothing,
      zio.aws.ec2.model.ModifyVpnTunnelOptionsSpecification.ReadOnly
    ] = ZIO.succeed(tunnelOptions)
    def getSkipTunnelReplacement: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("skipTunnelReplacement", skipTunnelReplacement)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ModifyVpnTunnelOptionsRequest
  ) extends zio.aws.ec2.model.ModifyVpnTunnelOptionsRequest.ReadOnly {
    override val vpnConnectionId: VpnConnectionId =
      zio.aws.ec2.model.primitives.VpnConnectionId(impl.vpnConnectionId())
    override val vpnTunnelOutsideIpAddress: String =
      impl.vpnTunnelOutsideIpAddress(): String
    override val tunnelOptions
        : zio.aws.ec2.model.ModifyVpnTunnelOptionsSpecification.ReadOnly =
      zio.aws.ec2.model.ModifyVpnTunnelOptionsSpecification
        .wrap(impl.tunnelOptions())
    override val skipTunnelReplacement: Optional[Boolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.skipTunnelReplacement())
        .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ModifyVpnTunnelOptionsRequest
  ): zio.aws.ec2.model.ModifyVpnTunnelOptionsRequest.ReadOnly = new Wrapper(
    impl
  )
}
